pub enum AuthError {
Client(Error),
StatusCode(Response),
ParseJson(Error),
Generic {
message: String,
},
RequestError(ReqwestError),
}Expand description
Box API errors
Variants
Client(Error)
The request couldn’t be completed because there was an error when trying to do so
StatusCode(Response)
The request was made, but the server returned an unsuccessful status
code, such as 404 or 503. In some cases, the response may contain a
custom message from Box.com with more information, which can be
serialized into Box_model::ApiError.
ParseJson(Error)
Generic
RequestError(ReqwestError)