Module rusty_box::error

source ·

Enums

  • Matches errors that are returned from the Spotfiy API as part of the JSON response object.
  • Groups up the kinds of errors that may happen in this crate.

Type Definitions