Module rusty_box::http_client

source ·
HTTP client module. This module contains the BaseHttpClient trait, which is implemented by the reqwest module.

Re-exports

Modules

  • This module contains the common traits and types used by the HTTP clients. Leaving the door open for developers to implement other http clients.
  • The client implementation for the reqwest HTTP client, which is async by default.