This module contains the common traits and types used by the HTTP clients. Leaving the door open for developers to implement other http clients.

Traits

  • This trait represents the interface to be implemented for an HTTP client, which is kept separate from the Box client for cleaner code. Thus, it also requires other basic traits that are needed for the Box client.

Type Definitions