Enum rusty_box::http_client::reqwest::ReqwestError
source · pub enum ReqwestError {
Client(Error),
StatusCode(Response),
}Variants
Client(Error)
The request couldn’t be completed because there was an error when trying to do so
StatusCode(Response)
The request was made, but the server returned an unsuccessful status
code, such as 404 or 503. In some cases, the response may contain a
custom message from Box with more information, which can be
serialized into rusty-box::AuthError (not yet really).