pub struct UserAllOfNotificationEmail {
pub email: Option<String>,
pub is_confirmed: Option<bool>,
}Expand description
UserAllOfNotificationEmail : An alternate notification email address to which email notifications are sent. When it’s confirmed, this will be the email address to which notifications are sent instead of to the primary email address.
Fields
email: Option<String>The email address to send the notifications to.
is_confirmed: Option<bool>Specifies if this email address has been confirmed.
Implementations
Sourceimpl UserAllOfNotificationEmail
impl UserAllOfNotificationEmail
Sourcepub fn new() -> UserAllOfNotificationEmail
pub fn new() -> UserAllOfNotificationEmail
An alternate notification email address to which email notifications are sent. When it’s confirmed, this will be the email address to which notifications are sent instead of to the primary email address.