Module rusty_box::auth::access_token
source · Expand description
Structures for the access token response from the Box API.
Structs
- AccessToken : A token that can be used to make authenticated API calls.
Enums
- The type of downscoped access token returned. This is only returned if an access token has been downscoped.
- The type of access token returned.