Module rusty_box::http_client
source · Expand description
HTTP client module.
This module contains the BaseHttpClient trait, which is implemented by the reqwest module.
Re-exports
pub use self::reqwest::ReqwestClient as HttpClient;pub use self::reqwest::ReqwestError as HttpError;pub use common::BaseHttpClient;pub use common::Form;pub use common::Headers;pub use common::Query;
Modules
- This module contains the common traits and types used by the HTTP clients. Leaving the door open for developers to implement other http clients.
- The client implementation for the reqwest HTTP client, which is async by default.