Module rusty_box::http_client::common
source · Traits
- This trait represents the interface to be implemented for an HTTP client, which is kept separate from the Spotify client for cleaner code. Thus, it also requires other basic traits that are needed for the Spotify client.