Enum rusty_box::http_client::reqwest::ReqwestError
source · pub enum ReqwestError {
Client(Error),
StatusCode(Response),
}Expand description
Custom enum that contains all the possible errors that may occur when using
reqwest.
Sample usage:
use rusty_box::http_client::{HttpError, HttpClient, BaseHttpClient};
let client = HttpClient::default();
let response = client.get("wrongurl", None, &Default::default()).await;
match response {
Ok(data) => println!("request succeeded: {:?}", data),
Err(HttpError::Client(e)) => eprintln!("request failed: {}", e),
Err(HttpError::StatusCode(response)) => {
let code = response.status().as_u16();
match response.json::<rusty_box::rest_api::api::models::client_error::ClientError>().await {
Ok(api_error) => eprintln!("status code {}: {:?}", code, api_error),
Err(_) => eprintln!("status code {}", code),
}
},
}Variants
Client(Error)
The request couldn’t be completed because there was an error when trying to do so
StatusCode(Response)
The request was made, but the server returned an unsuccessful status
code, such as 404 or 503. In some cases, the response may contain a
custom message from Spotify with more information, which can be
serialized into rusty-box::ApiError.