pub struct UserFull {Show 28 fields
pub id: Option<String>,
pub type: RHashType,
pub name: Option<String>,
pub login: Option<String>,
pub created_at: Option<String>,
pub modified_at: Option<String>,
pub language: Option<String>,
pub timezone: Option<String>,
pub space_amount: Option<i64>,
pub space_used: Option<i64>,
pub max_upload_size: Option<i64>,
pub status: Option<Status>,
pub job_title: Option<String>,
pub phone: Option<String>,
pub address: Option<String>,
pub avatar_url: Option<String>,
pub role: Option<Role>,
pub tracking_codes: Option<Vec<TrackingCode>>,
pub can_see_managed_users: Option<bool>,
pub is_sync_enabled: Option<bool>,
pub is_external_collab_restricted: Option<bool>,
pub is_exempt_from_device_limits: Option<bool>,
pub is_exempt_from_login_verification: Option<bool>,
pub enterprise: Option<Box<UserFullAllOfEnterprise>>,
pub my_tags: Option<Vec<String>>,
pub hostname: Option<String>,
pub is_platform_access_only: Option<bool>,
pub external_app_user_id: Option<String>,
}Expand description
UserFull : A full representation of a user, as can be returned from any user API endpoint.
Fields
id: Option<String>The unique identifier for this user
type: RHashTypeuser
name: Option<String>The display name of this user
login: Option<String>The primary email address of this user
created_at: Option<String>When the user object was created
modified_at: Option<String>When the user object was last modified
language: Option<String>The language of the user, formatted in modified version of the ISO 639-1 format.
timezone: Option<String>The user’s timezone
space_amount: Option<i64>The user’s total available space amount in bytes
space_used: Option<i64>The amount of space in use by the user
max_upload_size: Option<i64>The maximum individual file size in bytes the user can have
status: Option<Status>The user’s account status
job_title: Option<String>The user’s job title
phone: Option<String>The user’s phone number
address: Option<String>The user’s address
avatar_url: Option<String>URL of the user’s avatar image
role: Option<Role>The user’s enterprise role
tracking_codes: Option<Vec<TrackingCode>>Tracking codes allow an admin to generate reports from the admin console and assign an attribute to a specific group of users. This setting must be enabled for an enterprise before it can be used.
can_see_managed_users: Option<bool>Whether the user can see other enterprise users in their contact list
is_sync_enabled: Option<bool>Whether the user can use Box Sync
is_external_collab_restricted: Option<bool>Whether the user is allowed to collaborate with users outside their enterprise
is_exempt_from_device_limits: Option<bool>Whether to exempt the user from Enterprise device limits
is_exempt_from_login_verification: Option<bool>Whether the user must use two-factor authentication
enterprise: Option<Box<UserFullAllOfEnterprise>>Tags for all files and folders owned by the user. Values returned will only contain tags that were set by the requester.
hostname: Option<String>The root (protocol, subdomain, domain) of any links that need to be generated for the user
is_platform_access_only: Option<bool>Whether the user is an App User
external_app_user_id: Option<String>An external identifier for an app user, which can be used to look up the user. This can be used to tie user IDs from external identity providers to Box users.