Structs

Enums

Functions

  • Creates a new managed user in an enterprise. This endpoint is only available to users and applications with the right admin permissions.
  • Deletes a user. By default this will fail if the user still owns any content. Move their owned content first before proceeding, or use the force field to delete the user and their files.
  • Retrieves information about a user in the enterprise.
    The application and the authenticated user need to have the permission to look up users in the entire enterprise.
    This endpoint also returns a limited set of information for external users who are collaborated on content owned by the enterprise for authenticated users with the right scopes. In this case, disallowed fields will return null instead.
  • Returns a list of all users for the Enterprise along with their user_id, public_name, and login.
    The application and the authenticated user need to have the permission to look up users in the entire enterprise.
  • Retrieves information about the user who is currently authenticated.
    In the case of a client-side authenticated OAuth 2.0 application this will be the user who authorized the app.
    In the case of a JWT, server-side authenticated application this will be the service account that belongs to the application by default.
    Use the As-User header to change who this API call is made on behalf of.
  • Validates the roles and permissions of the user, and creates asynchronous jobs to terminate the user’s sessions. Returns the status for the POST request.
  • Validates the roles and permissions of the user, and creates asynchronous jobs to terminate the user’s sessions. Returns the status for the POST request.
  • Validates the roles and permissions of the user, and creates asynchronous jobs to terminate the user’s sessions. Returns the status for the POST request.
  • Updates a managed or app user in an enterprise. This endpoint is only available to users and applications with the right admin permissions.